pub struct CreateKeysetRequest<'a> {
pub name: Cow<'a, str>,
pub description: Cow<'a, str>,
pub client: Option<CreateClientSpec<'a>>,
}Expand description
Request message to create a new Keyset with the given name and description.
Requires the dataset:create scope.
Fields
name: Cow<'a, str>A human-readable name for the keyset.
Must be 1–64 characters using only A-Z a-z 0-9 _ - /. The name default is reserved.
description: Cow<'a, str>A description of the keyset.
client: Option<CreateClientSpec<'a>>Trait Implementations
Sourceimpl<'a> ComposeSchema for CreateKeysetRequest<'a>
impl<'a> ComposeSchema for CreateKeysetRequest<'a>
Sourceimpl<'a> Debug for CreateKeysetRequest<'a>
impl<'a> Debug for CreateKeysetRequest<'a>
Sourceimpl<'de, 'a> Deserialize<'de> for CreateKeysetRequest<'a>
impl<'de, 'a> Deserialize<'de> for CreateKeysetRequest<'a>
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Dummy<&'static str> for CreateKeysetRequest<'_>
Generate a random CreateDatasetRequest with a random description and the given name.
impl Dummy<&'static str> for CreateKeysetRequest<'_>
Generate a random CreateDatasetRequest with a random description and the given name.
Sourceimpl Dummy<Faker> for CreateKeysetRequest<'_>
Generate a random CreateDatasetRequest with a random name and description.
impl Dummy<Faker> for CreateKeysetRequest<'_>
Generate a random CreateDatasetRequest with a random name and description.
Sourceimpl<'a> Serialize for CreateKeysetRequest<'a>
impl<'a> Serialize for CreateKeysetRequest<'a>
Sourceimpl<'a> ToSchema for CreateKeysetRequest<'a>
impl<'a> ToSchema for CreateKeysetRequest<'a>
Sourceimpl<'a> Validate for CreateKeysetRequest<'a>
impl<'a> Validate for CreateKeysetRequest<'a>
Sourceimpl<'v_a, 'a> ValidateArgs<'v_a> for CreateKeysetRequest<'a>
impl<'v_a, 'a> ValidateArgs<'v_a> for CreateKeysetRequest<'a>