pub struct GeneratedKey {
pub key_material: ViturKeyMaterial,
pub tag: Vec<u8>,
pub decryption_policy: Option<DecryptionPolicy>,
}Expand description
Represents generated data key material which is used by the client to derive data keys with its own key material.
Returned in the response to a GenerateKeyRequest.
Fields
key_material: ViturKeyMaterialtag: Vec<u8>decryption_policy: Option<DecryptionPolicy>The decryption policy with server-generated MAC (tag_version >= 1 only).