pub struct LoadKeysetRequest {
pub client_id: Uuid,
pub keyset_id: Option<IdentifiedBy>,
}Expand description
Request to load a keyset on behalf of a client. This is used by clients before indexing or querying data and includes key material which can be derived by the client to generate encrypted index terms.
If a keyset_id is not provided the client’s default keyset will be loaded.
Requires the data_key:retrieve scope (though this may change in the future).
Response is a LoadKeysetResponse.
Fields
client_id: Uuidkeyset_id: Option<IdentifiedBy>The keyset to load. Accepts a UUID or a name string. If omitted, the client’s default keyset is used.