pub struct ModifyKeysetRequest<'a> {
pub keyset_id: IdentifiedBy,
pub name: Option<Cow<'a, str>>,
pub description: Option<Cow<'a, str>>,
}Expand description
Request message to modify a keyset with the given keyset_id.
name and description are optional and will be updated if provided.
Requires the dataset:modify scope.
Response is an EmptyResponse.
Fields
keyset_id: IdentifiedByThe keyset to modify. Accepts a UUID or a name string.
name: Option<Cow<'a, str>>Optional new name for the keyset.
description: Option<Cow<'a, str>>Optional new description for the keyset.