pub struct DecryptionPolicy {
pub conditions: Vec<PolicyCondition>,
}Expand description
A decryption policy: flat OR of identity claim conditions.
Used with tag_version=1. The policy conditions are included in the tag HMAC,
so stripping or swapping the policy causes a tag mismatch.
Stored alongside the ciphertext.
Fields
conditions: Vec<PolicyCondition>Trait Implementations
Sourceimpl Clone for DecryptionPolicy
impl Clone for DecryptionPolicy
Sourcefn clone(&self) -> DecryptionPolicy
fn clone(&self) -> DecryptionPolicy
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for DecryptionPolicy
impl ComposeSchema for DecryptionPolicy
Sourceimpl Debug for DecryptionPolicy
impl Debug for DecryptionPolicy
Sourceimpl<'de> Deserialize<'de> for DecryptionPolicy
impl<'de> Deserialize<'de> for DecryptionPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for DecryptionPolicy
impl PartialEq for DecryptionPolicy
Sourcefn eq(&self, other: &DecryptionPolicy) -> bool
fn eq(&self, other: &DecryptionPolicy) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DecryptionPolicy
impl Serialize for DecryptionPolicy
Sourceimpl ToSchema for DecryptionPolicy
impl ToSchema for DecryptionPolicy
impl Eq for DecryptionPolicy
impl StructuralPartialEq for DecryptionPolicy